==> bfilter-0.10.1.tar.gz: bfilter-0.10.1/main/HttpStateError.h <==
/*
    BFilter - a smart ad-filtering web proxy
    Copyright (C) 2002-2004  Joseph Artsimovich <joseph_a@mail.ru>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#ifndef HTTPSTATEERROR_H_
#define HTTPSTATEERROR_H_

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include "HttpState.h"
#include "ErrorDescriptor.h"
#include <string>
#include <memory>

class HttpStateError : public HttpState
{
public:
	HttpStateError();
	
	virtual ~HttpStateError();
	
	void activate(std::string const& errmsg) {
		m_errorMessage = errmsg;
	}
	
	void activate(std::auto_ptr<ErrorDescriptor> err_desc) {
		m_ptrErrDesc = err_desc;
	}
	
	std::auto_ptr<ErrorDescriptor>& errorDescriptor() {
		return m_ptrErrDesc;
	}
	
	std::auto_ptr<ErrorDescriptor> const& errorDescriptor() const {
		return m_ptrErrDesc;
	}
	
	std::string const& errorMessage() const { return m_errorMessage; }
	
	virtual void cleanup();
	
	virtual HttpState* processNewData(
		SplittableBuffer& input, bool eof,
		SplittableBuffer& body_data, bool& body_eof);
private:
	std::auto_ptr<ErrorDescriptor> m_ptrErrDesc;
	std::string m_errorMessage;
};

#endif

==> bfilter_1.0.6.orig.tar.gz: bfilter-1.0.6/main/HttpStateError.h <==
/*
    BFilter - a smart ad-filtering web proxy
    Copyright (C) 2002-2004  Joseph Artsimovich <joseph_a@mail.ru>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#ifndef HTTPSTATEERROR_H_
#define HTTPSTATEERROR_H_

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include "HttpState.h"
#include "ErrorDescriptor.h"
#include "IntrusivePtr.h"
#include <string>

class HttpStateError : public HttpState
{
public:
	HttpStateError();
	
	virtual ~HttpStateError();
	
	void activate(std::string const& errmsg) {
		m_errorMessage = errmsg;
	}
	
	void activate(IntrusivePtr<ErrorDescriptor> const& err_desc) {
		m_ptrErrDesc = err_desc;
	}
	
	IntrusivePtr<ErrorDescriptor>& errorDescriptor() {
		return m_ptrErrDesc;
	}
	
	IntrusivePtr<ErrorDescriptor> const& errorDescriptor() const {
		return m_ptrErrDesc;
	}
	
	std::string const& errorMessage() const { return m_errorMessage; }
	
	virtual void cleanup();
	
	virtual HttpState* processNewData(
		SplittableBuffer& input, bool eof,
		SplittableBuffer& body_data, bool& body_eof);
private:
	IntrusivePtr<ErrorDescriptor> m_ptrErrDesc;
	std::string m_errorMessage;
};

#endif
